#
# spec file for package perl-Mac-PropertyList
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mac-PropertyList
Name:           perl-Mac-PropertyList
Version:        1.504
Release:        1.5
License:        Artistic-2.0
Summary:        Work with Mac plists at a low level
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/B/BD/BDFOY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.64
BuildRequires:  perl(Test::More) >= 1
BuildRequires:  perl(XML::Entities)
BuildRequires:  perl(parent)
Requires:       perl(XML::Entities)
Requires:       perl(parent)
%{perl_requires}

%description
This module is a low-level interface to the Mac OS X Property List (plist)
format in either XML or binary. You probably shouldn't use this in
applications–build interfaces on top of this so you don't have to put all
the heinous multi-level object stuff where people have to look at it.

You can parse a plist file and get back a data structure. You can take that
data structure and get back the plist as XML. If you want to change the
structure inbetween that's your business. :)

You don't need to be on Mac OS X to use this. It simply parses and
manipulates a text format that Mac OS X uses.

If you need to work with the old ASCII or newer JSON formet, you can use
the *plutil* tool that comes with MacOS X:

	% plutil -convert xml1 -o ExampleBinary.xml.plist ExampleBinary.plist

Or, you can extend this module to handle those formats (and send a pull
request).

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CITATION.cff examples
%license LICENSE

%changelog
* Sat Jul  9 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.504
  see /usr/share/doc/packages/perl-Mac-PropertyList/Changes
  1.504 2022-07-08T03:16:18Z
  * @trwyant fixed some stray debugging output (#14 and #15)
* Fri Jul  1 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.503
  see /usr/share/doc/packages/perl-Mac-PropertyList/Changes
  1.503 2022-06-30T18:16:29Z
  * Darren Kulp noted an XML error in one of the test strings (GitHub #12)
  * No other code changes
* Wed Jan 20 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.502
  see /usr/share/doc/packages/perl-Mac-PropertyList/Changes
  1.502 2021-01-19T10:17:29Z
  * freshen distro, dump Travis CI, add Github Actions
* Sun Oct  4 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.501
  see /usr/share/doc/packages/perl-Mac-PropertyList/Changes
  1.501 2020-09-30T04:50:46Z
  * Added create_plist_from_string()
  * Merged Tom Wyant's code to handle CF$UID types
  * A few more things emit warnings if they don't get the right type
  * $XML_{head,foot} are now subroutines
* Fri Mar 23 2018 coolo@suse.com
- updated to 1.413
  see /usr/share/doc/packages/perl-Mac-PropertyList/Changes
  1.413 2018-03-22T18:51:07Z
  * Update to Artistic License 2.0
* Mon Jul 31 2017 coolo@suse.com
- updated to 1.412
  see /usr/share/doc/packages/perl-Mac-PropertyList/Changes
  1.412 2017-07-30T18:27:33Z
  * Fix for plist files with comments (bram.stappers@tiobe.com) RT #122466
  and GitHub #5 (as a pull request)
  * Note that this module does not handle ASCII or JSON formats (but they
  are in the wishlist now) (anonymous Yahoo! user)
* Fri Jul 21 2017 coolo@suse.com
- updated to 1.411
  see /usr/share/doc/packages/perl-Mac-PropertyList/Changes
* Wed Jul 19 2017 coolo@suse.com
- updated to 1.411
  see /usr/share/doc/packages/perl-Mac-PropertyList/Changes
* Sat Feb  7 2015 coolo@suse.com
- updated to 1.41
  * Fix up some metadata (GitHub #4)
* Sun Feb  9 2014 coolo@suse.com
- updated to 1.40
  * Get rid of MYMETA
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.39
  * Bump to full release
  * Fix non-portable strftime format (RT #83460)
  * Wim Lewis improved the binary reader / writer and made better
    tests for it.
* Wed Jun  5 2013 coolo@suse.com
- updated to 1.38
    Wim Lewis <wiml@cpan.org> added WriteBinary. Great work!
* Wed Sep 26 2012 Greg.Freemyer@gmail.com
- ran spec-cleaner
- upgrade to v1.37
  * fix plist_as_perl to be the same as as_perl (and as documented)
  * Update the docs, and make the previous dev releases official
  * Document the as_perl method, which undecorates that internal
* Tue Aug 23 2011 chris@computersalat.de
- fix deps
  * perl >= 5.10.0
* Sat Jul 30 2011 Greg.Freemyer@opensuse.com
- upgrade to 1.34
  * In ReadBinary, handle the data as big-endian. This means you
    need the > pack modifier introduced in 5.10.
  * Require 5.10 because I need the > pack modifier
  * Ensure binary reads are for big endian
  * Various cleanups for format and whitespace
* Mon Feb 21 2011 Greg.Freemyer@gmail.com
- initial package 1.33
  * created by cpanspec 1.78.03
